@@ -1,23 +1,20 @@
 module Hint.Eval (
-
       interpret, as, infer,
-      eval ,parens)
+      unsafeInterpret,
+      eval, parens
+) where
 
-where
+import qualified GHC.Exts (unsafeCoerce#)
 
-import qualified GHC.Exts ( unsafeCoerce# )
-
-import Data.Typeable hiding ( typeOf )
-import qualified Data.Typeable ( typeOf )
+import Data.Typeable hiding (typeOf)
+import qualified Data.Typeable (typeOf)
 
 import Hint.Base
 import Hint.Context
 import Hint.Parsers
-import Hint.Sandbox
 import Hint.Util
 
-import qualified Hint.Compat as Compat
-
+import qualified Hint.GHC as GHC
 
 -- | Convenience functions to be used with @interpret@ to provide witnesses.
 --   Example:
@@ -33,26 +30,28 @@ infer = undefined
 interpret :: (MonadInterpreter m, Typeable a) => String -> a -> m a
 interpret expr wit = unsafeInterpret expr (show $ Data.Typeable.typeOf wit)
 
-
 unsafeInterpret :: (MonadInterpreter m) => String -> String -> m a
-unsafeInterpret expr type_str = sandboxed go expr
-  where go e =
-         do -- First, make sure the expression has no syntax errors,
-            -- for this is the only way we have to "intercept" this
-            -- kind of errors
-            failOnParseError parseExpr e
-            --
-            let expr_typesig = concat [parens e, " :: ", type_str]
-            expr_val <- mayFail $ runGhc1 Compat.compileExpr expr_typesig
-            --
-            return (GHC.Exts.unsafeCoerce# expr_val :: a)
+unsafeInterpret expr type_str =
+    do -- First, make sure the expression has no syntax errors,
+       -- for this is the only way we have to "intercept" this
+       -- kind of errors
+       failOnParseError parseExpr expr
+       --
+       let expr_typesig = concat [parens expr, " :: ", type_str]
+       expr_val <- mayFail $ runGhc1 compileExpr expr_typesig
+       --
+       return (GHC.Exts.unsafeCoerce# expr_val :: a)
+
+-- add a bogus Maybe, in order to use it with mayFail
+compileExpr :: GHC.GhcMonad m => String -> m (Maybe GHC.HValue)
+compileExpr = fmap Just . GHC.compileExpr
 
 -- | @eval expr@ will evaluate @show expr@.
 --  It will succeed only if @expr@ has type t and there is a 'Show'
 --  instance for t.
 eval :: MonadInterpreter m => String -> m String
-eval expr = do in_scope_show   <- support_show
-               in_scope_String <- support_String
+eval expr = do in_scope_show   <- supportShow
+               in_scope_String <- supportString
                let show_expr = unwords [in_scope_show, parens expr]
                unsafeInterpret show_expr in_scope_String
 
@@ -66,5 +65,5 @@ eval expr = do in_scope_show   <- support_show
 -- Solution: @parens s = \"(let {foo =\n\" ++ s ++ \"\\n ;} in foo)\"@ where @foo@ does not occur in @s@
 parens :: String -> String
 parens s = concat ["(let {", foo, " =\n", s, "\n",
-                    "                     ;} in ", foo, ")"]
+                   "                     ;} in ", foo, ")"]
     where foo = safeBndFor s
